.. VIPCCA documentation master file, created by
   sphinx-quickstart on Wed Dec 23 10:19:34 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

VIPCCA - Variational Inference 
=========================================================

.. toctree::
   :maxdepth: 2

   installation
   tutorials/index.rst
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
